<?php

function CleanType($TypeID, $TypeName, $TypeNameView, $TypeArray, $ErrorArray)
{
	$TypeArray = Set_Check($TypeArray, '');
	$ErrorArray['E_'.$TypeName] = "<b>Invalid ".$TypeNameView.":</b><br />Please select one from the list.";

	$TypeID = trim(escapeshellcmd($TypeID));

	if ($TypeID)
	{
		foreach ($TypeArray as $Row)
		{
			if ($TypeID == $Row[$TypeName.'ID'])
			{
				$ErrorArray['E_'.$TypeName] = '';
			}
		}
	}
	return array($TypeID, $ErrorArray);
}



function CleanTextString($TextString, $TextStringName, $TextStringViewName, $Length, $NullOK, $ErrorArray)
{
	$ErrorArray['E_'.$TextStringName] = "<b>Invalid ".$TextStringViewName.":</b><br />".$TextStringViewName." must be ".$Length." characters or less.";
	$TextString = trim(escapeshellcmd($TextString));

	if ((!$TextString) && ($NullOK == 1)) // could combine this with the next if but broken apart for readability.
	{
		$ErrorArray['E_'.$TextStringName] = '';
	}
	elseif (($TextString) && (strlen($TextString) <= $Length)) // i.e. the TextString was not all spaces & check length
	{
//		$TextString = addslashes($TextString);   ----- not needed b/c magic quotes is on.
		$ErrorArray['E_'.$TextStringName] = '';
	}
	return array($TextString, $ErrorArray);
}



function CleanYear($Year, $YearName, $YearNameView, $NullOK, $ErrorArray)
{
	$ErrorArray['E_'.$YearName] = "<b>Invalid ".$YearNameView.":</b><br />".$TextStringViewName." must be between 1900 and 2099 or be 0000 for no date.";
	$Year = trim(escapeshellcmd($Year));

	if (((!$Year) && ($NullOK == 1)) || (($Year) && (ereg('(0{4})|((19|20)[0-9]{2})', $Year)))) // year must always be 4-digits, result can be either '0000' or 1st 2 must be 19 or 20, and the last 2 can be 0-9
	{
		$ErrorArray['E_'.$YearName] = '';
	}

	return array($Year, $ErrorArray);
}



function CleanMonth($Month, $MonthName, $MonthNameView, $NullOK, $ErrorArray)
{
	$ErrorArray['E_'.$MonthName] = "<b>Invalid ".$MonthNameView.":</b><br />".$TextStringViewName." must be between 01 and 12.";
	$Month = trim(escapeshellcmd($Month));


	if ((!$Month) && ($NullOK == 1))
	{
		$ErrorArray['E_'.$MonthName] = '';
	}
	elseif ((strlen($Month)==1) && (ereg('[1-9]', $Month))) // single digit
	{
		$Month = '0'.$Month;
		$ErrorArray['E_'.$MonthName] = '';
	}
	elseif ((strlen($Month)==2) && (ereg('(0[1-9])|(1[0-2])', $Month))) // 2 digits
	{
		$ErrorArray['E_'.$MonthName] = '';
	}

	return array($Month, $ErrorArray);
}



function CleanDay($Day, $DayName, $DayNameView, $NullOK, $ErrorArray)
{
	$ErrorArray['E_'.$DayName] = "<b>Invalid ".$DayNameView."</b><br />".$DayNameView." must be between 01 and 31 and appropriate for the month selected.";
	$Day = trim(escapeshellcmd($Day));

	if ((!$Day) && ($NullOK == 1))
	{
		$ErrorArray['E_'.$DayName] = '';
	}
	elseif((strlen($Day)==1) && (ereg('[1-9]', $Day))) // single digit
	{
		$Day = '0'.$Day;
		$ErrorArray['E_'.$DayName] = '';
	}
	elseif ((strlen($Day)==2) && (ereg('0[1-9]|[1-2][0-9]|3[0-1]', $Day))) // 2 digits
	{
		$ErrorArray['E_'.$DayName] = '';
	}

	return array($Day, $ErrorArray);
}



function CleanDate($Day, $Month, $Year, $DayName, $MonthName, $YearName, $DateName, $DayNameView, $MonthNameView, $YearNameView, $DateNameView, $NullOK, $ErrorArray)
{
	if(((($Day == '00') && ($Month == '00') && ($Year == '00')) || ((!$Day) && (!$Month) && (!$Year))) && ($NullOK == 1))
	{return array($Day, $Month, $Year, $ErrorArray);}
	else
	{
		list($Year, $ErrorArray) = CleanYear($Year, $YearName, $YearNameView, 0, $ErrorArray);
		list($Month, $ErrorArray) = CleanMonth($Month, $MonthName, $MonthNameView, 0, $ErrorArray);
		list($Day, $ErrorArray) = CleanDay($Day, $DayName, $DayNameView, 0, $ErrorArray);

		if (($ErrorArray['E_'.$DayName]=='')&&($ErrorArray['E_'.$MonthName]=='')&&($ErrorArray['E_'.$YearName]=='')) // all three dates are valid
		{
			if(checkdate($Month, $Day, $Year) == false) // if date is not valid, MUST be day that doesn't fit.
			{
				$ErrorArray['E_'.$DateName] = "<b>Invalid ".$DateNameView."</b><br />The Day must match up with the month. i.e. February can not have 30 days.";
			}
		}
		return array($Day, $Month, $Year, $ErrorArray);
	}
}



function CleanDate2($Date, $DateName, $DateNameView, $ErrorArray) // used for combined dates in the YYYY-MM-DD format.
{
	if ($Date != '0000-00-00')
	{
		$DateArray = explode("-", $Date);

		list($DateArray[0], $ErrorArray) = CleanYear($DateArray[0], $DateName, 'Year', 0, $ErrorArray);
		list($DateArray[1], $ErrorArray) = CleanMonth($DateArray[1], $DateName, 'Month', 0, $ErrorArray);
		list($DateArray[2], $ErrorArray) = CleanDay($DateArray[2], $DateName, 'Day', 0, $ErrorArray);

		if (($ErrorArray['E_'.$DayName]=='')&&($ErrorArray['E_'.$MonthName]=='')&&($ErrorArray['E_'.$YearName]=='')) // all three dates are valid
		{
			if(checkdate($DateArray[1], $DateArray[2], $DateArray[0]) == false) // if date is not valid, MUST be date that doesn't fit.
			{
				$ErrorArray['E_'.$DateName] = "<b>Invalid ".$DateNameView.":</b><br />These are required fields.<br />Also, day must match up with the month. i.e. February can not have 30 days.";
			}
		}

		$Date = implode("-", $DateArray);
	}

	return array($Date, $ErrorArray);
}



function CleanTwoChoice($Field, $FieldName, $FieldNameView, $Value1, $Value2, $Value1Name, $Value2Name, $ErrorArray)
{
	$ErrorArray['E_'.$FieldName] = "<b>Invalid ".$FieldViewName.":</b> Please choose ".$Value1Name." or ".$Value2Name.".";

	if(($Field == $Value1) || ($Field == $Value2))
	{
		$ErrorArray['E_'.$FieldName] = '';
	}
	return array($Field, $ErrorArray);
}



function CleanZipPiece($Zip, $ZipName, $ZipNameView, $NullOK, $Length, $ErrorArray)
{
	$ErrorArray['E_'.$ZipName] = "<b>Invalid ".$ZipNameView."</b> ".$ZipNameView." must be ".$Length." digits (numbers).";
	$Zip = trim(escapeshellcmd($Zip));
	if ((!$Zip) && ($NullOK == 1)) // could combine this with the next if but broken apart for readability.
	{
		$ErrorArray['E_'.$ZipName] = '';
	}
	elseif (($Zip) && (strlen($Zip) <= $Length) && (eregi('^[0-9]+$', $Zip))) // i.e. the TextString was not all spaces & check length & that it is all numbers
	{
		$Zip = addslashes($Zip);
		$ErrorArray['E_'.$ZipName] = '';
	}
	return array($Zip, $ErrorArray);
}



function CleanZip($Zip5, $Zip4, $Zip5Name, $Zip4Name, $NullOK, $ErrorArray)
{
	list($Zip5, $ErrorArray) = CleanZipPiece($Zip5, $Zip5Name, 'Zip-5', 1, 5, $ErrorArray);
	list($Zip4, $ErrorArray) = CleanZipPiece($Zip4, $Zip4Name, 'Zip-4', 1, 4, $ErrorArray);

	if ((strlen($Zip5)==0)&&(strlen($Zip4)>0)) // if Zip4 has something & Zip5 doesn't, error.
	{
		$ErrorArray['E_Zip'] = "<b>Invalid Zip:</b> Zip-5 can not be blank if Zip-4 is not.";
	}
	return array($Zip5, $Zip4, $ErrorArray);
}



function CleanState($StateTwoLetter, $StateName, $NullOK, $ErrorArray)
{
	$StateListArray = Set_Check('StateListArray','');
	$ErrorArray['E_'.$StateName] = "<b>Invalid State:</b><br />Please select a state from the list.";
	$StateTwoLetter = trim(escapeshellcmd($StateTwoLetter));
	if($StateTwoLetter == -1) // if no selection from a drop down, the select value is -1.
	{
		$StateTwoLetter = '';
	}
	if ((!$StateTwoLetter) && ($NullOK == 1))
	{
		$ErrorArray['E_'.$StateName] = '';
	}
	elseif (($StateTwoLetter) && (strlen($StateTwoLetter) == 2))
	{
		foreach ($StateListArray as $Row)
		{
			if ($StateTwoLetter == $Row['StateTwoLetter'])
			{$ErrorArray['E_'.$StateName] = '';}
		}
	}
	return array($StateTwoLetter, $ErrorArray);
}



function CleanStateRegionCountry($StateTwoLetter, $Region, $Country, $StateName, $RegionName, $CountryName, $ErrorArray)
{
	list($StateTwoLetter, $ErrorArray) = CleanState($StateTwoLetter, $StateName, 1, $ErrorArray);
	list($Region, $ErrorArray) = CleanTextString($Region, $RegionName, 'Region', 30, 1, $ErrorArray);
	list($Country, $ErrorArray) = CleanTextString($Country, $CountryName, 'Country', 30, 1, $ErrorArray);

	if (($Country == 'US') || ($Country == 'America') || ($Country == 'United States') || ($Country == 'United States of America') || (!$Country))
	{
		$Country = 'USA';
	}

	if ((($Country == 'USA') && ($Region)) || (($Country != 'USA') && ($StateTwoLetter)) || (($Region) && ($StateTwoLetter))) // if Country is USA there must be a State and NOT a Reigon. If country != USA there must NOT be a state. If there is a Region or state, there can NOT be the other.
	{
		$ErrorArray['E_StateRegionCountry'] = "<b>Invalid State, Region & Country Combination:</b><br />Region is only for non-USA addresses.<br />If Country is not USA there must NOT be a state.<br />If there is a Region or State, there can NOT be the other.";
	}
	return array($StateTwoLetter, $Region, $Country, $ErrorArray);
}



function CleanCurrency($Amt, $CurrencyName, $CurrencyNameView, $Length, $NullOK, $ErrorArray)
{
	$ErrorArray['E_'.$CurrencyName] = "<b>Invalid ".$CurrencyNameView.":</b> ".$CurrencyNameView." must be a decimal number.";
	$Amt = trim(escapeshellcmd($Amt));

	if ((!$Amt) && ($NullOK == 1))
	{$ErrorArray['E_'.$CurrencyName] = '';}
	elseif ((ereg('^([0-9])+(\.)?[0-9]?[0-9]?', $Amt)) && (ereg('[^a-zA-Z_\-]', $Amt)))
	{
		// Add .00 if no decimal exists
		if (!strpos($Amt, '.'))
		{$Amt .= '.00';}

		// Add a zero if there is only a single digit to the right of the decimal
		if (strpos($Amt, '.') == (strlen($Amt) - 2))
		{$Amt .='0';}

		// Drop any digit more than 2 places to the right of the decimal point
		while (strrpos($Amt, '.') < (strlen($Amt) - 3))
		{
			$Amt = substr($Amt, 0, -1);
		}

		// get rid of all leading zeros except if 0.xx
//		while (strpos($Amt, '0') == 0)
		while (substr($Amt, 0) == '0')
		{
			if (strpos($Amt, '.') == 1)
			{break;}

			$Amt = substr($Amt, 1);
		}
		{$ErrorArray['E_'.$CurrencyName] = '';}
	}	
	return array($Amt, $ErrorArray);
}



function CleanIDNumber($IDNum, $IDName, $IDNameView, $ErrorArray)
{
	$ErrorArray['E_'.$IDName] = "<b>Invalid ".$IDNameView.":</b><br />Please select a ".$IDNameView.".";
	$IDNum = trim(escapeshellcmd($IDNum));

	if ((eregi('^[0-9]+$', $IDNum)) || ($IDNum == 'New'))
	{$ErrorArray['E_'.$IDName] = '';}

	return array($IDNum, $ErrorArray);
}

function CleanNumber($Num, $NumName, $NumNameView, $Length, $NullOK, $ErrorArray)
{
	$ErrorArray['E_'.$NumName] = "<b>Invalid ".$NumNameView.":</b><br />".$NumNameView." can only be whole numbers<br />(no decimals, letter or otherwise).";
	$Num = trim(escapeshellcmd($Num));

	if ((eregi('^[0-9]+$', $Num)) && (strlen($Num) <= $Length))
	{$ErrorArray['E_'.$NumName] = '';}

	return array($Num, $ErrorArray);
}



?>